@@ -1,5 +1,5 @@
 from AGCoder import Coder
-from query_where import AGQueryWhere
+from .query_where import AGQueryWhere
 
 
 class AGJsonToSQL:
